@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="de_DE">
 <context>
     <name>NetFileChooseEdit</name>
     <message>
@@ -153,7 +155,7 @@
     </message>
     <message>
         <source>View all network configurations</source>
-        <translation>Alle Netzwerk-onfigurationen zeigen</translation>
+        <translation>Alle Netzwerk-Konfigurationen zeigen</translation>
     </message>
     <message>
         <source>Details has been copied</source>
@@ -485,8 +487,8 @@
         <translation>Verbinden</translation>
     </message>
     <message>
-        <source>My Networks</source>
-        <translation>Meine Netzwerke</translation>
+        <source>My&#xa0;Networks</source>
+        <translation>Meine&#xa0;Netzwerke</translation>
     </message>
     <message>
         <source>Other Networks</source>
@@ -648,6 +650,18 @@
         <source>Gateway</source>
         <translation>Gateway</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation type="unfinished">Ungültiger Gateway</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionIPv6</name>
@@ -703,6 +717,18 @@
         <source>Gateway</source>
         <translation>Gateway</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation type="unfinished">Ungültiger Gateway</translation>
+    </message>
 </context>
 <context>
     <name>SectionPPP</name>
@@ -1720,4 +1746,4 @@
         <translation>Netzwerk</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
