@@ -1,312 +1,310 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="hu">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
 <context>
     <name>dde::network::DockContentWidget</name>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Hálózati beállítások</translation>
+        <translation>Hálózati beállítások</translation>
     </message>
     <message>
         <source>Network Detection</source>
-        <translation type="unfinished"></translation>
+        <translation>Hálózat érzékelése</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>Tiltsa le a &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Repülőgép üzemmódot&lt;/a&gt; először, ha vezeték nélküli hálózathoz szeretne kapcsolódni</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">IP cím ütközés</translation>
+        <translation>IP cím ütközés</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Hálózat</translation>
+        <translation>Hálózat</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 Csatlakozása</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 csatlakozva</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 lekapcsolódva</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nem sikerült csatlakozni a %1 eszközhöz, kérjük ellenőrizze a routert, vagy a hálózati kábelt.</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>Nem sikerült csatlakozni a %1 -eszközhöz, kérjük próbálja meg közelebb vinni a routerhez</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>A csatlakozás sikertelen, nem sikerült csatlakozni a %1-hez, helytelen jelszó</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Jelszó szükséges a %1 csatlakoztatásához</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>A %1 802.11 vezeték nélküli hálózat nem található</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>A %1 csatlakozáshoz bejelentkezés után állítsa be hitelesítési adatait</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Jelszó</translation>
+        <translation>Jelszó</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>Privát jelszó</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>Kulcs</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Proxy jelszó</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Csoport jelszó</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>Felhasználónév</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">Név (SSID)</translation>
+        <translation>Név (SSID)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">Mégsem</translation>
+        <translation>Mégsem</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">Kapcsolódás</translation>
+        <translation>Kapcsolódás</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">Vezetékes kapcsolat letiltása</translation>
+        <translation>Vezetékes kapcsolat letiltása</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">Vezetékes kapcsolat engedélyezése</translation>
+        <translation>Vezetékes kapcsolat engedélyezése</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">Vezeték-nélküli kapcsolat letiltása</translation>
+        <translation>Vezeték nélküli kapcsolat megszüntetése</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">Vezeték nélküli kapcsolat engedélyezése</translation>
+        <translation>Vezeték nélküli kapcsolat engedélyezése</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">Hálózat letiltása</translation>
+        <translation>Hálózat letiltása</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">Hálózat engedélyezése</translation>
+        <translation>Hálózat engedélyezése</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN letiltása</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN engedélyezése</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Rendszer proxy letiltása</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Rendszer proxy engedélyezése</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Hálózati beállítások</translation>
+        <translation>Hálózati beállítások</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>Több szolgáltatás is elindult</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Csatlakozva ehhez: %1</translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Rendszer proxy engedélyezve</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">Csatlakozva</translation>
+        <translation>Csatlakozva</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>Hálózat Ki</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">A hálózati kábel kihúzva</translation>
+        <translation>A hálózati kábel kihúzva</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">Nincs csatlakozva</translation>
+        <translation>Nincs csatlakozva</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">Csatlakozás</translation>
+        <translation>Csatlakozás</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">Csatlakoztatva, de nincs internet hozzáférés</translation>
+        <translation>Csatlakoztatva, de nincs internet hozzáférés</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">A kapcsolódás sikertelen</translation>
+        <translation>A kapcsolódás sikertelen</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">IP cím ütközés</translation>
+        <translation>IP cím ütközés</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Vezeték nélküli hálózat</translation>
+        <translation>Vezeték nélküli hálózat</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 csatlakoztatva</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>Ki</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Vezetékes hálózat </translation>
+        <translation>Vezetékes hálózat </translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Hálózat</translation>
+        <translation>Hálózat</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Rendszer proxy </translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>A VPN-konfiguráció nincs csatlakoztatva, vagy nem sikerült csatlakozni. Kérjük &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;keresse fel a Vezérlőpultot&lt;/a&gt; az ellenőrzéséhez.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Vezetékes hálózat </translation>
+        <translation>Vezetékes hálózat </translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Vezeték nélküli hálózat</translation>
+        <translation>Vezeték nélküli hálózat</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">Csatlakozás rejtett hálózathoz</translation>
+        <translation>Csatlakozás rejtett hálózathoz</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Hálózataim</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Egyéb Hálózatok</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetworkPlugin</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Hálózat</translation>
+        <translation>Hálózat</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
