@@ -40,7 +40,7 @@ NetworkModule::NetworkModule(QObject *parent)
     , m_replacesId(0)
     , m_contentWidget(new QWidget)
 {
-    m_isLockModel = !QCoreApplication::applicationName().contains("greeter");
+    m_isLockModel = QCoreApplication::applicationName().contains("lock", Qt::CaseInsensitive);
 
     m_contentWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
     QVBoxLayout *mainLayout = new QVBoxLayout(m_contentWidget);
@@ -171,8 +171,9 @@ void NetworkModule::installTranslator(const QString &locale)
     }
     localTmp = locale;
     QApplication::removeTranslator(&translator);
-    translator.load(QLocale(locale), "dss-network-plugin", "_", "/usr/share/dss-network-plugin/translations");
-    QApplication::installTranslator(&translator);
+    if (translator.load(QLocale(locale), "dss-network-plugin", "_", "/usr/share/dss-network-plugin/translations")) {
+        QApplication::installTranslator(&translator);
+    }
     m_manager->updateLanguage(localTmp);
 }
 
