@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="az">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
 <context>
     <name>Bubble</name>
     <message>
@@ -12,290 +10,290 @@
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>Simsiz şəbəkəyə qoşulmaq istəyirsinizsə öncə &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Uçuş rejimi&lt;/a&gt;ni söndürün</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">İP ziddiyyəti</translation>
+        <translation>İP ziddiyyəti</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Şəbəkə</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; qoşulur</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; qoşuldu</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; ilə bağlantı kəsildi</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; ilə bağlantı mümkün deyil, lütfən routerinizi və ya şəbəkə kabelinizi yoxlayın.</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; ilə bağlantı mümkün deyil, lütfən simsiz router cihazınıza yaxınlaşın.</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>Bağlantı alınmadı, &quot;%1&quot; ilə bağlantı mümkün deyil, şifrə səhvdir</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; ilə bağlantı üçün şifrə tələb olunur</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; 802.11 WLAN şəbəkəsi tapılmadı</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; ilə bağlantı yaratmaq üçün, daxil olduqdan sonra kimlik doğrulaması məlumatlarınızı ayarlayın</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Şifrə</translation>
+        <translation>Şifrə</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>Məxfi şifrə</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>açar</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Proksi şifrəsi</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Qrup şifrəsi</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>İstifadəçi adı</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">Ad (SSİD)</translation>
+        <translation>Ad (SSİD)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">İmtina</translation>
+        <translation>Ləğv edin</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">Qoşulun</translation>
+        <translation>Qoşulun</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">Simli bağlantını söndürmək</translation>
+        <translation>Simli bağlantını söndürün</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">Simli bağlantını qoşmaq</translation>
+        <translation>Simli bağlantını qoşun</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">Simsiz bağlantını söndürmək</translation>
+        <translation>Simsiz bağlantını söndürün</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">Simsiz bağlantını qoşmaq</translation>
+        <translation>Simsiz bağlantını qoşun</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">Şəbəkəni söndürmək</translation>
+        <translation>Şəbəkəni söndürün</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">Şəbəkəni qoşmaq</translation>
+        <translation>Şəbəkəni qoşun</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Şəbəkə ayarları</translation>
+        <translation>Şəbəkə ayarları</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">Qoşuldu</translation>
+        <translation>Qoşuldu</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>Şəbəkəni söndürülüb</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">Şəbəkə kabeli çıxarılıb</translation>
+        <translation>Şəbəkə kabeli çıxarılıb</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">Bağlantı yoxdur</translation>
+        <translation>Bağlantı yoxdur</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">Qoşulur...</translation>
+        <translation>Qoşulur</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">Qoşulub, lakin internetə giriş yoxdur</translation>
+        <translation>Qoşulub, lakin internetə giriş yoxdur</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">Qoşulma alınmadı</translation>
+        <translation>Qoşulma alınmadı</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">İP ziddiyyəti</translation>
+        <translation>İP ziddiyyəti</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Simsiz şəbəkə</translation>
+        <translation>Simsiz şəbəkə</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 qoşuldu</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>Söndürülüb</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Simli şəbəkə</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Şəbəkə</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Simli şəbəkə</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Simsiz şəbəkə</translation>
+        <translation>Simsiz şəbəkə</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">Gizli şəbəkəyə qoşulun</translation>
+        <translation>Gizli şəbəkəyə qoşulun</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Şəbəkələrim</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Başqa şəbəkələr</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
