@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ja">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
 <context>
     <name>Bubble</name>
     <message>
@@ -12,290 +10,290 @@
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>ワイヤレスネットワークに接続するには、&lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;機内モード&lt;/a&gt;を無効化してください。</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished"></translation>
+        <translation>IP競合</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>ネットワーク</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>有線接続 %1</translation>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN L2TP %1</translation>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN PPTP %1</translation>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN VPNC %1</translation>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenVPN %1</translation>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN StrongSwan %1</translation>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenConnect %1</translation>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>PPPoE 接続 %1</translation>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; に接続中</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; 接続にされました</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; から切断されました</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; に接続できませんでした。ルーターやケーブルを確認してください。</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; に接続できませんでした。もっとワイヤレスルーターに近づいてください。</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>接続失敗、&quot;%1&quot; に接続できませんでした。パスワードが間違っています。</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; に接続するには、パスワードが必要です。</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; 802.11 無線LANネットワークが見つかりませんでした。</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; に接続するには、ログイン後に認証鵜情報を構成する必要があります。</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">パスワード</translation>
+        <translation>パスワード</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>プライベートパスワード</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>キー</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>プロキシパスワード</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>グループパスワード</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>ユーザー名</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished"></translation>
+        <translation>名前(SSID)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">キャンセル</translation>
+        <translation>キャンセル</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">接続</translation>
+        <translation>接続</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">有線接続を無効にする</translation>
+        <translation>有線接続を無効化</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">有線接続を有効にする</translation>
+        <translation>有線接続を有効化</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">無線接続を無効にする</translation>
+        <translation>無線接続を無効化</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">無線接続を有効にする</translation>
+        <translation>無線接続を有効化</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">ネットワークを無効にする</translation>
+        <translation>ネットワークを無効化</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">ネットワークを有効にする</translation>
+        <translation>ネットワークを有効化</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>VPNを無効化</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>VPNを有効化</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>システムプロキシを無効化</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>システムプロキシを有効化</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">ネットワーク設定</translation>
+        <translation>ネットワーク設定</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>複数のサービスが開始されました</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>接続先: %1</translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>システムプロキシが有効化されました</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">接続済み</translation>
+        <translation>接続済み</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>ネットワーク off</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">ネットワークケーブル未接続</translation>
+        <translation>ネットワークケーブル未接続</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">未接続</translation>
+        <translation>未接続</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">接続試行中</translation>
+        <translation>接続中</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">接続済み、インターネットアクセスなし</translation>
+        <translation>接続済み、インターネットアクセスなし</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished"></translation>
+        <translation>接続に失敗しました</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished"></translation>
+        <translation>IP競合</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">無線ネットワーク</translation>
+        <translation>無線ネットワーク</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 に接続されました</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>Off</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">有線ネットワーク</translation>
+        <translation>有線ネットワーク</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>ネットワーク</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>システムプロキシ</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN構成が接続されていないか、接続に失敗しました。&lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;コントロールセンターで確認&lt;/a&gt;してください。</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">有線ネットワーク</translation>
+        <translation>有線ネットワーク</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">無線ネットワーク</translation>
+        <translation>無線ネットワーク</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">非表示のネットワークへ接続</translation>
+        <translation>非表示のネットワークへ接続</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>マイ ネットワーク</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>その他のネットワーク</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
