@@ -3,7 +3,7 @@
     <name>network::systemservice::NetworkInitialization</name>
     <message>
         <source>Wired Connection</source>
-        <translation type="unfinished"/>
+        <translation>Connexion filaire</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
